@@ -3,10 +3,11 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide musical cadence chords
 
-our $VERSION = '0.0504';
+our $VERSION = '0.0600';
 
 use Moo;
 use Music::Chord::Note;
+use Music::Note;
 use Music::Scales;
 use Music::ToRoman;
 
@@ -34,7 +35,7 @@ has octave => (
 
 has format => (
     is      => 'ro',
-    default => sub { '' },
+    default => sub { 'isobase' },
 );
 
 
@@ -129,10 +130,17 @@ sub _generate_chord {
             s/b/f/;
         }
     }
+    elsif ( $self->format eq 'midinum' ) {
+        $octave ||= 4;
+        @notes = map { Music::Note->new( $_ . $octave, 'ISO' )->format('midinum') } @notes;
+    }
+    elsif ( $self->format ne 'isobase' ) {
+        die 'unknown format';
+    }
 
     # Append the octave if requested
     @notes = map { $_ . $octave } @notes
-        if $octave;
+        if $octave && $self->format ne 'midinum';
 
     return \@notes;
 }
@@ -151,7 +159,7 @@ Music::Cadence - Provide musical cadence chords
 
 =head1 VERSION
 
-version 0.0504
+version 0.0600
 
 =head1 SYNOPSIS
 
@@ -190,6 +198,14 @@ version 0.0504
   $chords = $mc->cadence( type => 'perfect' );
   # [['Gs5','C5','Ds5'], ['Cs5','F5','Gs5']]
 
+  $mc = Music::Cadence->new(
+    key    => 'C',
+    format => 'midinum',
+  );
+
+  $chords = $mc->cadence( type => 'perfect' );
+  # [[67,71,62], [60,64,67]]
+
 =head1 DESCRIPTION
 
 C<Music::Cadence> provides musical cadence chords.
@@ -226,8 +242,13 @@ append."
 
 =head2 format
 
+The output format to use.  Default: C<isobase> (i.e. "bare note
+names")
+
 If C<midi>, convert sharp C<#> to C<s> and flat C<b> to C<f> after
-chord generation.  Default: C<''> (none)
+chord generation.
+
+If C<midinum>, convert notes to their numerical MIDI equivalents.
 
 =head1 METHODS
 
@@ -294,6 +315,8 @@ L<Moo>
 
 L<Music::Chord::Note>
 
+L<Music::Note>
+
 L<Music::Scales>
 
 L<Music::ToRoman>
@@ -304,6 +327,8 @@ L<https://www.musictheoryacademy.com/how-to-read-sheet-music/cadences/>
 
 =head1 TO DO
 
+Use L<Music::Chord::Positions>!
+
 Evaded cadence
 
 Imperfect cadences
